/*
 * Copyright 2019 by Kappich Systemberatung Aachen
 * ALL RIGHTS RESERVED.
 */

package de.bsvrz.pat.sysbed.permissions;

import de.bsvrz.dav.daf.accessControl.UserInfo;
import de.bsvrz.dav.daf.accessControl.internal.UserAction;
import de.bsvrz.dav.daf.main.config.AttributeGroupUsage;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Ein Zustand der Rechteprüfugn zur Visualisierung
 *
 * @author Kappich Systemberatung
 */
public class PermissionsState {

	private InnerState _sender;
	private InnerState _receiver;
	private InnerState _source;
	private InnerState _drain;

	public PermissionsState(final UserInfo userPermissions, final SystemObject obj, final AttributeGroupUsage usage) {

		_sender =   mapState(userPermissions.maySubscribeData(obj, usage.getAttributeGroup(), usage.getAspect(), UserAction.SENDER));
		_receiver = mapState(userPermissions.maySubscribeData(obj, usage.getAttributeGroup(), usage.getAspect(), UserAction.RECEIVER));
		_source =   mapState(userPermissions.maySubscribeData(obj, usage.getAttributeGroup(), usage.getAspect(), UserAction.SOURCE));
		_drain =    mapState(userPermissions.maySubscribeData(obj, usage.getAttributeGroup(), usage.getAspect(), UserAction.DRAIN));

		switch(usage.getUsage()) {
			case OnlineDataAsSenderDrain:
				if(_receiver == InnerState.Allowed) {
					_receiver = InnerState.AllowedWrongUsage;
				}
				else {
					_receiver = InnerState.Ignore;
				}
				if(_source == InnerState.Allowed) {
					_source = InnerState.AllowedWrongUsage;
				}
				else {
					_source = InnerState.Ignore;
				}
				break;
			case OnlineDataAsSourceReceiverOrSenderDrain:
				if(_sender == InnerState.Allowed) {
					_sender = InnerState.AllowedWrongUsage;
				}
				else {
					_sender = InnerState.Ignore;
				}
				if(_drain == InnerState.Allowed) {
					_drain = InnerState.AllowedWrongUsage;
				}
				else {
					_drain = InnerState.Ignore;
				}
				break;
		}

	}

	public InnerState getSender() {
		return _sender;
	}

	public InnerState getReceiver() {
		return _receiver;
	}

	public InnerState getSource() {
		return _source;
	}

	public InnerState getDrain() {
		return _drain;
	}

	@Override
	public boolean equals(final Object o) {
		if(this == o) return true;
		if(!(o instanceof PermissionsState)) return false;

		final PermissionsState that = (PermissionsState) o;

		if(_sender != that._sender) return false;
		if(_receiver != that._receiver) return false;
		if(_source != that._source) return false;
		return _drain == that._drain;
	}

	@Override
	public int hashCode() {
		int result = _sender.hashCode();
		result = 31 * result + _receiver.hashCode();
		result = 31 * result + _source.hashCode();
		result = 31 * result + _drain.hashCode();
		return result;
	}

	private static InnerState mapState(final boolean maySubscribeData) {
		return maySubscribeData ? InnerState.Allowed : InnerState.Forbidden;
	}

	public enum InnerState {
		
		Allowed,
		Forbidden,
		AllowedWrongUsage,
		Ignore,
		
	}
}
